pub enum PatientError {
Show 42 variants
InvalidInput(String),
StorageDirCreation(Error),
PatientDirCreation(Error),
CleanupAfterInitialiseFailed {
path: PathBuf,
init_error: Box<PatientError>,
cleanup_error: Error,
},
FileWrite(Error),
FileRead(Error),
Serialization(Error),
Deserialization(Error),
YamlSerialization(Error),
YamlDeserialization(Error),
Openehr(OpenEhrError),
Fhir(FhirError),
Uuid(UuidError),
GitInit(Error),
GitIndex(Error),
GitAdd(Error),
GitWriteTree(Error),
GitFindTree(Error),
GitSignature(Error),
GitCommit(Error),
PemParse(PemError),
EcdsaPrivateKeyParse(Box<dyn Error + Send + Sync>),
EcdsaPublicKeyParse(Box<dyn Error + Send + Sync>),
AuthorCertificatePublicKeyMismatch,
InvalidCommitSignaturePayload,
EcdsaSign(Box<dyn Error + Send + Sync>),
GitCommitBuffer(Error),
GitCommitSigned(Error),
CommitBufferToString(FromUtf8Error),
GitOpen(Error),
GitReference(Error),
GitHead(Error),
GitSetHead(Error),
GitPeel(Error),
InvalidTimestamp,
MissingAuthorName,
MissingAuthorRole,
InvalidAuthorRegistration,
ReservedAuthorTrailerKey,
InvalidCareLocation,
MissingCareLocation,
ReservedCareLocationTrailerKey,
}Expand description
Comprehensive error type for all VPR operations.
This enum represents all possible failure modes in the VPR system, from basic I/O operations to complex cryptographic validation. Each variant includes relevant context and follows consistent naming and documentation patterns.
The error messages are designed to be informative for both developers debugging issues and operators maintaining production systems.
Variants
InvalidInput(String)
StorageDirCreation(Error)
PatientDirCreation(Error)
CleanupAfterInitialiseFailed
FileWrite(Error)
FileRead(Error)
Serialization(Error)
Deserialization(Error)
YamlSerialization(Error)
YamlDeserialization(Error)
Openehr(OpenEhrError)
Fhir(FhirError)
Uuid(UuidError)
GitInit(Error)
GitIndex(Error)
GitAdd(Error)
GitWriteTree(Error)
GitFindTree(Error)
GitSignature(Error)
GitCommit(Error)
PemParse(PemError)
EcdsaPrivateKeyParse(Box<dyn Error + Send + Sync>)
EcdsaPublicKeyParse(Box<dyn Error + Send + Sync>)
AuthorCertificatePublicKeyMismatch
InvalidCommitSignaturePayload
EcdsaSign(Box<dyn Error + Send + Sync>)
GitCommitBuffer(Error)
GitCommitSigned(Error)
CommitBufferToString(FromUtf8Error)
GitOpen(Error)
GitReference(Error)
GitHead(Error)
GitSetHead(Error)
GitPeel(Error)
InvalidTimestamp
MissingAuthorName
MissingAuthorRole
InvalidAuthorRegistration
ReservedAuthorTrailerKey
InvalidCareLocation
MissingCareLocation
ReservedCareLocationTrailerKey